# pmlab-lite
A Process Mining scripting environment.

### Installation
pmlab-lite requires graphviz to run the helper functions that draw petri nets to .PDF-files.

So optionally get graphviz through your package manager:
```sh
$ sudo apt-get install graphviz               #example for ubuntu/debian systems
```
Install pmlab-lite from pypi using pip:
```sh
$ pip install pmlab-lite
```


### License
GNU General Public License 3.0
